==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Minga messatge de fòro',

	// B
	'bouton_radio_articles_futurs' => 'ai articles futurs unicament (minga d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'a toi lu articles sensa excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à toi lu articles, levats aquelu que lo fòro es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilisaires si devon abonar en donant li sieui adreças e-mail denant de poder postar li contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion <i>à priòri</i> (li contribucions apareisson pas publicament après validacion dai administrators).',
	'bouton_radio_modere_abonnement' => 'sus abonament',
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri',
	'bouton_radio_modere_priori' => 'moderacion à priòri',
	'bouton_radio_publication_immediate' => 'Publicacion immediata dei messatges (li contribucions apareisson sus lo còup que son mandadi, lu administrators li poadon suprimir pi).',

	// D
	'documents_interdits_forum' => 'Documents proïbits dins lo fòro',

	// E
	'erreur_enregistrement_message' => 'Lo voaste messatge a pas poscut èstre registrat per l’encausa d’un problèma tècnico',
	'extensions_autorisees' => 'Extensions autorizadi:',
	'extensions_autorisees_toutes' => 'toti',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?',
	'forum' => 'Fòro',
	'forum_acces_refuse' => 'Podètz pas plus accedir en aquelu forums.',
	'forum_attention_dix_caracteres' => '<b>Dàida !</b> lo voastre messatge deu aver au manco dètz caractèrs.',
	'forum_attention_message_non_poste' => 'Mèfi, avetz pas postat lo voastre messatge!',
	'forum_attention_nb_caracteres_mini' => '<b>Daida!</b> Lo voastre messatge dèu contenir au manco @min@ caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Dàida !</b> lo voastre titre deu aver au manco tres caractèrs.',
	'forum_attention_trop_caracteres' => '<b>Daida !</b> lo voastre messatge es tròp long (@compte@ caractèrs) : per si poder registrar, cau pas que passe @max@ caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat :',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aquí</a> per continuar.',
	'forum_envoyer' => 'Mandar',
	'forum_forum' => 'fòro',
	'forum_info_modere' => 'Aqueu fòro es moderat à priòri: la voastra contribucion apareisserà après èstre estada validada da un administrator dau site.',
	'forum_lien_hyper' => 'Ligam ipertèxt',
	'forum_message' => 'Lo voastre messatge',
	'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
	'forum_message_trop_long' => 'Lo voastre messatge es tròup lòng. La talha maximala es de 20 000 caractèrs.',
	'forum_ne_repondez_pas' => 'Respondatz pas à-n-aquel e-mail ma sus lo fòro à l’adreça seguenta : ',
	'forum_page_url' => '(se lo voastre messatge si referisse à un article publicat sus lo web, ò à una pàgina que fornisse mai d’informacions, podetz marcar çai sota lo titre de la pàgina e la sieu adreça.)',
	'forum_permalink' => 'Estac permanent vers lo comentàri',
	'forum_poste_par' => 'Messatge postat @parauteur@ à la seguida de l’article « @titre@ ».',
	'forum_poste_par_court' => 'Messatge postat@parauteur@.',
	'forum_poste_par_generique' => 'Messatge postat@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Cu siètz ?',
	'forum_texte' => 'Tèxt dau voastre messatge',
	'forum_titre' => 'Titre',
	'forum_url' => 'Lo voastre site oèb',
	'forum_valider' => 'Validar aquesta chausida',
	'forum_voir_avant' => 'Previsualisar',
	'forum_votre_email' => 'La voastra adreça e-mail',
	'forum_votre_nom' => 'Lo voastre nom',
	'forum_vous_enregistrer' => 'Per participar à
  aquest fòro, vos devètz registrar d’en premier. Mercé
  d’indicar çai sota l’identificant personau que vos es
  estat fornit. Se siètz pas registrat, devètz',
	'forum_vous_inscrire' => 'vos marcar.',

	// I
	'icone_bruler_message' => 'Sinhalar coma Espam',
	'icone_bruler_messages' => 'Sinhalar coma Espam',
	'icone_legitimer_message' => 'Sinhalar coma licit',
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau fòro public : @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerar lu fòros',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_supprimer_messages' => 'Suprimir aquelu messatges',
	'icone_valider_message' => 'Validar aqueu messatge',
	'icone_valider_messages' => 'Validar aquelu messatges',
	'icone_valider_repondre_message' => 'Validar & Respoandre en-aquest messatge',
	'info_1_message_forum' => '1 messatge de fòro',
	'info_activer_forum_public' => '<i>Per activar lu fòros publics, vorguètz chausir lu sieus mòdos
 de moderacion predefinits:</i>',
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion :',
	'info_config_forums_prive_admin' => 'Un fòro reservat ai administrators dau site:',
	'info_config_forums_prive_global' => 'Un fòro total, duvbert en toi lu redactors:',
	'info_config_forums_prive_objets' => 'Un fòro sota cada article, brèva, site referençat, eca.:',
	'info_desactiver_forum_public' => 'Desactivar l’utilisacion dei fòros publics. Lu fòros publics podràn èstre autorisats au cas per cas sus lu articles; seràn proïbits sus li rubricas, brèvas, eca.',
	'info_envoi_forum' => 'Mandadís dei fòros ai autors dei articles',
	'info_fonctionnement_forum' => 'Foncionament dau fòro :',
	'info_forcer_previsualisation_court' => 'Forçar la previsualizacion',
	'info_forums_liees_mot' => 'Lu messatges de fòro ligats en aquèu mòt',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>seguit dei fòros</i> es un òutis de gestion dau voastre site (mas es pas un espaci de discussion ò de redaccion). Fa paréisser toti li contribucions dei fòros dau site, autant ben aqueli dau site public coma de l’espaci privat e vos permete de gerar aquesti contribucions.',
	'info_liens_syndiques_3' => 'fòros',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'fòro',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en aspèra de validacion',
	'info_liens_texte' => 'Estac(s) contengut(s) dins lo tèxto dau messatge',
	'info_liens_titre' => 'Estac(s) contengut(s) dins lo titre dau messatge',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei fòros publics',
	'info_nb_messages_forum' => '@nb@ messatges de fòro',
	'info_option_email' => 'Quora un visitaire dau sit poasta un messatge novèu dins lo fòro associat à un article, lu autors de l’article poadon èstre avertits d’aqueu messatge per corrier electronic. Indicatz per cada tipe de fòro se cau utilisar aquela opcion.',
	'info_pas_de_forum' => 'Minga de fòro',
	'info_selectionner_message' => 'Selecionar lu messatges :',
	'interface_formulaire' => 'Interfaça formulàri',
	'item_activer_forum_administrateur' => 'Activar lo fòro dei administrators',
	'item_config_forums_prive_global' => 'Activar lo fòro dei redactors',
	'item_config_forums_prive_objets' => 'Activar aquelu fòros',
	'item_desactiver_forum_administrateur' => 'Desactivar lo fòro dei administrators',
	'item_non_config_forums_prive_global' => 'Desactivar lo fòro dei redactors',
	'item_non_config_forums_prive_objets' => 'Desactivar aquelu fòros',

	// L
	'label_selectionner' => 'Selecionar:',
	'lien_reponse_article' => 'Respoasta à l’article',
	'lien_reponse_breve_2' => 'Respoasta à la brèva',
	'lien_reponse_message' => 'Respoasta au messatge',
	'lien_reponse_rubrique' => 'Respoasta à la rubrica',
	'lien_reponse_site_reference' => 'Respoasta au sit referençat',
	'lien_vider_selection' => 'Vuar la selecion',

	// M
	'messages_aucun' => 'Minga',
	'messages_meme_auteur' => 'Toi lu messatges d’aquel autor',
	'messages_meme_email' => 'Toi lu messatges d’aquel mèl',
	'messages_meme_ip' => 'Toi lu messatges d’aquela IP',
	'messages_off' => 'Suprimits',
	'messages_perso' => 'Personaus',
	'messages_privadm' => 'Administrators',
	'messages_prive' => 'Privats',
	'messages_privoff' => 'Suprimits',
	'messages_privrac' => 'Generaus',
	'messages_publie' => 'Publicats',
	'messages_spam' => 'Espam',
	'messages_tous' => 'Toi',

	// O
	'onglet_messages_internes' => 'Messatges internes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respoandre à-n-aqueu messatge',

	// S
	'statut_off' => 'Suprimit',
	'statut_original' => 'originau',
	'statut_publie' => 'Publicat',
	'statut_spam' => 'Espam',

	// T
	'texte_messages_publics' => 'Messatges publics sus:',
	'titre_cadre_forum_administrateur' => 'Fòro privat dei administrators',
	'titre_cadre_forum_interne' => 'Fòro interne',
	'titre_config_forums_prive' => 'Fòros de l’espaci privat',
	'titre_forum' => 'Fòro',
	'titre_forum_suivi' => 'Seguit dei fòros',
	'titre_page_forum_suivi' => 'Seguit dei fòros',
	'titre_selection_action' => 'Selecion',
	'tout_voir' => 'Veire toi lu messatges',

	// V
	'voir_messages_objet' => 'veire lu messatges'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Minga messatge de fòro',

	// B
	'bouton_radio_articles_futurs' => 'ai articles futurs unicament (minga d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'a toi lu articles sensa excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à toi lu articles, levats aquelu que lo fòro es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilisaires si devon abonar en donant li sieui adreças e-mail denant de poder postar li contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion <i>à priòri</i> (li contribucions apareisson pas publicament après validacion dai administrators).',
	'bouton_radio_modere_abonnement' => 'sus abonament',
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri',
	'bouton_radio_modere_priori' => 'moderacion à priòri',
	'bouton_radio_publication_immediate' => 'Publicacion immediata dei messatges (li contribucions apareisson sus lo còup que son mandadi, lu administrators li poadon suprimir pi).',

	// D
	'documents_interdits_forum' => 'Documents proïbits dins lo fòro',

	// E
	'erreur_enregistrement_message' => 'Lo voaste messatge a pas poscut èstre registrat per l’encausa d’un problèma tècnico',
	'extensions_autorisees' => 'Extensions autorizadi:',
	'extensions_autorisees_toutes' => 'toti',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?',
	'forum' => 'Fòro',
	'forum_acces_refuse' => 'Podètz pas plus accedir en aquelu forums.',
	'forum_attention_dix_caracteres' => '<b>Dàida !</b> lo voastre messatge deu aver au manco dètz caractèrs.',
	'forum_attention_message_non_poste' => 'Mèfi, avetz pas postat lo voastre messatge!',
	'forum_attention_nb_caracteres_mini' => '<b>Daida!</b> Lo voastre messatge dèu contenir au manco @min@ caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Dàida !</b> lo voastre titre deu aver au manco tres caractèrs.',
	'forum_attention_trop_caracteres' => '<b>Daida !</b> lo voastre messatge es tròp long (@compte@ caractèrs) : per si poder registrar, cau pas que passe @max@ caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat :',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aquí</a> per continuar.',
	'forum_envoyer' => 'Mandar',
	'forum_forum' => 'fòro',
	'forum_info_modere' => 'Aqueu fòro es moderat à priòri: la voastra contribucion apareisserà après èstre estada validada da un administrator dau site.',
	'forum_lien_hyper' => 'Ligam ipertèxt',
	'forum_message' => 'Lo voastre messatge',
	'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
	'forum_message_trop_long' => 'Lo voastre messatge es tròup lòng. La talha maximala es de 20 000 caractèrs.',
	'forum_ne_repondez_pas' => 'Respondatz pas à-n-aquel e-mail ma sus lo fòro à l’adreça seguenta : ',
	'forum_page_url' => '(se lo voastre messatge si referisse à un article publicat sus lo web, ò à una pàgina que fornisse mai d’informacions, podetz marcar çai sota lo titre de la pàgina e la sieu adreça.)',
	'forum_permalink' => 'Estac permanent vers lo comentàri',
	'forum_poste_par' => 'Messatge postat @parauteur@ à la seguida de l’article « @titre@ ».',
	'forum_poste_par_court' => 'Messatge postat@parauteur@.',
	'forum_poste_par_generique' => 'Messatge postat@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Cu siètz ?',
	'forum_texte' => 'Tèxt dau voastre messatge',
	'forum_titre' => 'Titre',
	'forum_url' => 'Lo voastre site oèb',
	'forum_valider' => 'Validar aquesta chausida',
	'forum_voir_avant' => 'Previsualisar',
	'forum_votre_email' => 'La voastra adreça e-mail',
	'forum_votre_nom' => 'Lo voastre nom',
	'forum_vous_enregistrer' => 'Per participar à
  aquest fòro, vos devètz registrar d’en premier. Mercé
  d’indicar çai sota l’identificant personau que vos es
  estat fornit. Se siètz pas registrat, devètz',
	'forum_vous_inscrire' => 'vos marcar.',

	// I
	'icone_bruler_message' => 'Sinhalar coma Espam',
	'icone_bruler_messages' => 'Sinhalar coma Espam',
	'icone_legitimer_message' => 'Sinhalar coma licit',
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau fòro public : @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerar lu fòros',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_supprimer_messages' => 'Suprimir aquelu messatges',
	'icone_valider_message' => 'Validar aqueu messatge',
	'icone_valider_messages' => 'Validar aquelu messatges',
	'icone_valider_repondre_message' => 'Validar & Respoandre en-aquest messatge',
	'info_1_message_forum' => '1 messatge de fòro',
	'info_activer_forum_public' => '<i>Per activar lu fòros publics, vorguètz chausir lu sieus mòdos
 de moderacion predefinits:</i>',
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion :',
	'info_config_forums_prive_admin' => 'Un fòro reservat ai administrators dau site:',
	'info_config_forums_prive_global' => 'Un fòro total, duvbert en toi lu redactors:',
	'info_config_forums_prive_objets' => 'Un fòro sota cada article, brèva, site referençat, eca.:',
	'info_desactiver_forum_public' => 'Desactivar l’utilisacion dei fòros publics. Lu fòros publics podràn èstre autorisats au cas per cas sus lu articles; seràn proïbits sus li rubricas, brèvas, eca.',
	'info_envoi_forum' => 'Mandadís dei fòros ai autors dei articles',
	'info_fonctionnement_forum' => 'Foncionament dau fòro :',
	'info_forcer_previsualisation_court' => 'Forçar la previsualizacion',
	'info_forums_liees_mot' => 'Lu messatges de fòro ligats en aquèu mòt',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>seguit dei fòros</i> es un òutis de gestion dau voastre site (mas es pas un espaci de discussion ò de redaccion). Fa paréisser toti li contribucions dei fòros dau site, autant ben aqueli dau site public coma de l’espaci privat e vos permete de gerar aquesti contribucions.',
	'info_liens_syndiques_3' => 'fòros',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'fòro',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en aspèra de validacion',
	'info_liens_texte' => 'Estac(s) contengut(s) dins lo tèxto dau messatge',
	'info_liens_titre' => 'Estac(s) contengut(s) dins lo titre dau messatge',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei fòros publics',
	'info_nb_messages_forum' => '@nb@ messatges de fòro',
	'info_option_email' => 'Quora un visitaire dau sit poasta un messatge novèu dins lo fòro associat à un article, lu autors de l’article poadon èstre avertits d’aqueu messatge per corrier electronic. Indicatz per cada tipe de fòro se cau utilisar aquela opcion.',
	'info_pas_de_forum' => 'Minga de fòro',
	'info_selectionner_message' => 'Selecionar lu messatges :',
	'interface_formulaire' => 'Interfaça formulàri',
	'item_activer_forum_administrateur' => 'Activar lo fòro dei administrators',
	'item_config_forums_prive_global' => 'Activar lo fòro dei redactors',
	'item_config_forums_prive_objets' => 'Activar aquelu fòros',
	'item_desactiver_forum_administrateur' => 'Desactivar lo fòro dei administrators',
	'item_non_config_forums_prive_global' => 'Desactivar lo fòro dei redactors',
	'item_non_config_forums_prive_objets' => 'Desactivar aquelu fòros',

	// L
	'label_selectionner' => 'Selecionar:',
	'lien_reponse_article' => 'Respoasta à l’article',
	'lien_reponse_breve_2' => 'Respoasta à la brèva',
	'lien_reponse_message' => 'Respoasta au messatge',
	'lien_reponse_rubrique' => 'Respoasta à la rubrica',
	'lien_reponse_site_reference' => 'Respoasta au sit referençat',
	'lien_vider_selection' => 'Vuar la selecion',

	// M
	'messages_aucun' => 'Minga',
	'messages_meme_auteur' => 'Toi lu messatges d’aquel autor',
	'messages_meme_email' => 'Toi lu messatges d’aquel mèl',
	'messages_meme_ip' => 'Toi lu messatges d’aquela IP',
	'messages_off' => 'Suprimits',
	'messages_perso' => 'Personaus',
	'messages_privadm' => 'Administrators',
	'messages_prive' => 'Privats',
	'messages_privoff' => 'Suprimits',
	'messages_privrac' => 'Generaus',
	'messages_publie' => 'Publicats',
	'messages_spam' => 'Espam',
	'messages_tous' => 'Toi',

	// O
	'onglet_messages_internes' => 'Messatges internes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respoandre à-n-aqueu messatge',

	// S
	'statut_off' => 'Suprimit',
	'statut_original' => 'originau',
	'statut_publie' => 'Publicat',
	'statut_spam' => 'Espam',

	// T
	'texte_messages_publics' => 'Messatges publics sus:',
	'titre_cadre_forum_administrateur' => 'Fòro privat dei administrators',
	'titre_cadre_forum_interne' => 'Fòro interne',
	'titre_config_forums_prive' => 'Fòros de l’espaci privat',
	'titre_forum' => 'Fòro',
	'titre_forum_suivi' => 'Seguit dei fòros',
	'titre_page_forum_suivi' => 'Seguit dei fòros',
	'titre_selection_action' => 'Selecion',
	'tout_voir' => 'Veire toi lu messatges',

	// V
	'voir_messages_objet' => 'veire lu messatges',
];
